"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const PredictableSupportCode_1 = __importDefault(require("../src/PredictableSupportCode"));
const fake_cucumber_1 = require("@cucumber/fake-cucumber");
describe('PredictableSupportCode', () => {
    context('#addPredictableBeforeHook', () => {
        const supportCode = new fake_cucumber_1.SupportCode();
        const predictableSupportCode = new PredictableSupportCode_1.default(supportCode);
        const scenarioId = 'some-scenario-id';
        const pickle = {
            astNodeIds: [scenarioId],
            id: 'some-pickle-id',
            language: 'en',
            tags: [],
            steps: [],
            uri: 'some-uri',
            name: 'Some Name',
        };
        beforeEach(() => {
            predictableSupportCode.addPredictableBeforeHook('some/where:7', scenarioId, 'passed');
        });
        it('adds a beforeHook', () => {
            assert_1.default.strictEqual(supportCode.beforeHooks.length, 1);
        });
        it('adds a beforeHook that matches the pickle from the scenario', () => {
            const hook = supportCode.beforeHooks[0];
            assert_1.default.notStrictEqual(hook.match(pickle), null);
        });
        it('adds a beforeHook with correct location', () => {
            const hook = supportCode.beforeHooks[0];
            const expected = {
                uri: 'some/where',
                location: { line: 7 },
            };
            assert_1.default.deepStrictEqual(hook.toMessage().hook.sourceReference, expected);
        });
        it('adds a hook with a passed status when status is "passed"', () => {
            const hook = supportCode.beforeHooks[0];
            assert_1.default.strictEqual(hook.status, 'PASSED');
        });
        it('adds a hook with a failed status when status is "failed"', () => {
            const supportCode = new fake_cucumber_1.SupportCode();
            const predictableSupportCode2 = new PredictableSupportCode_1.default(supportCode);
            predictableSupportCode2.addPredictableBeforeHook('some/where:7', scenarioId, 'failed', 0.01, 'BOOM !!');
            const hook = supportCode.beforeHooks[0];
            assert_1.default.strictEqual(hook.status, 'FAILED');
            assert_1.default.strictEqual(hook.errorMessage, 'BOOM !!');
            assert_1.default.strictEqual(hook.duration, 0.01);
        });
    });
    context('#addPredictableAfterHook', () => {
        const supportCode = new fake_cucumber_1.SupportCode();
        const predictableSupportCode2 = new PredictableSupportCode_1.default(supportCode);
        const scenarioId = 'some-scenario-id';
        const pickle = {
            astNodeIds: [scenarioId],
            id: 'some-pickle-id',
            language: 'en',
            tags: [],
            steps: [],
            uri: 'some-uri',
            name: 'Some Name',
        };
        beforeEach(() => {
            predictableSupportCode2.addPredictableAfterHook('some/where:7', scenarioId, 'passed');
        });
        it('adds a beforeHook', () => {
            assert_1.default.strictEqual(supportCode.afterHooks.length, 1);
        });
        it('adds a beforeHook that matches the pickle from the scenario', () => {
            const hook = supportCode.afterHooks[0];
            assert_1.default.notStrictEqual(hook.match(pickle), null);
        });
        it('adds a beforeHook with correct location', () => {
            const hook = supportCode.afterHooks[0];
            const sourceReference = {
                uri: 'some/where',
                location: {
                    line: 7,
                },
            };
            assert_1.default.deepStrictEqual(hook.toMessage().hook.sourceReference, sourceReference);
        });
        it('adds a hook with a passed status when status is "passed"', () => {
            const hook = supportCode.afterHooks[0];
            assert_1.default.strictEqual(hook.status, 'PASSED');
        });
        it('adds a hook with a failed status when status is "failed"', () => {
            const supportCode = new fake_cucumber_1.SupportCode();
            const predictableSupportCode2 = new PredictableSupportCode_1.default(supportCode);
            predictableSupportCode2.addPredictableAfterHook('some/where:7', scenarioId, 'failed', 0.12, 'BOOM !!');
            const hook = supportCode.afterHooks[0];
            assert_1.default.strictEqual(hook.status, 'FAILED');
            assert_1.default.strictEqual(hook.errorMessage, 'BOOM !!');
            assert_1.default.strictEqual(hook.duration, 0.12);
        });
    });
    context('.addPredictableStepDefinition', () => {
        const supportCode = new fake_cucumber_1.SupportCode();
        const predictableSupportCode = new PredictableSupportCode_1.default(supportCode);
        const stepId = 'some-step-id';
        const picklestep = {
            astNodeIds: [stepId],
            text: 'hello',
            id: 'step-id',
        };
        beforeEach(() => {
            predictableSupportCode.addPredictableStepDefinition('somewhere/over/the/rain.bow:2', stepId, 'passed');
        });
        it('registers the step definition', () => {
            assert_1.default.strictEqual(supportCode.stepDefinitions.length, 1);
        });
        it('creates a stepDefinition that matches the step id', () => {
            const stepDefinition = supportCode.stepDefinitions[0];
            assert_1.default.notStrictEqual(stepDefinition.match(picklestep), null);
        });
        it('creates a stepDefinition with correct location', () => {
            const stepDefinition = supportCode.stepDefinitions[0];
            const sourceReference = {
                uri: 'somewhere/over/the/rain.bow',
                location: {
                    line: 2,
                },
            };
            assert_1.default.deepStrictEqual(stepDefinition.toMessage().stepDefinition.sourceReference, sourceReference);
        });
        context('when a status is provided', () => {
            it('creates a StepDefinition with status passed for "passed"', () => {
                const supportCode = new fake_cucumber_1.SupportCode();
                const predictableSupportCode = new PredictableSupportCode_1.default(supportCode);
                predictableSupportCode.addPredictableStepDefinition('somewhere/over/the/rain.bow:2', stepId, 'passed');
                const stepDefinition = supportCode.stepDefinitions[0];
                assert_1.default.strictEqual(stepDefinition.status, 'PASSED');
            });
            it('creates a StepDefinition with status pending for "pending"', () => {
                const supportCode = new fake_cucumber_1.SupportCode();
                const predictableSupportCode = new PredictableSupportCode_1.default(supportCode);
                predictableSupportCode.addPredictableStepDefinition('somewhere/over/the/rain.bow:2', stepId, 'pending');
                const stepDefinition = supportCode.stepDefinitions[0];
                assert_1.default.strictEqual(stepDefinition.status, 'PENDING');
            });
            it('creates a StepDefinition with status failed for "failed"', () => {
                const supportCode = new fake_cucumber_1.SupportCode();
                const predictableSupportCode = new PredictableSupportCode_1.default(supportCode);
                predictableSupportCode.addPredictableStepDefinition('somewhere/over/the/rain.bow:2', stepId, 'failed', 1.23, 'something wrong happened');
                const stepDefinition = supportCode.stepDefinitions[0];
                assert_1.default.strictEqual(stepDefinition.status, 'FAILED');
                assert_1.default.strictEqual(stepDefinition.duration, 1.23);
            });
        });
    });
});
//# sourceMappingURL=PredictableSupportCodeTest.js.map